/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*******************************************************************************
* MPIA, NEVEC - MIDI project
*
* "@(#) $Id: history.c,v 1.4 2002/05/08 21:34:35 jdejong Exp $"
*
* who        when      what
* ---------  --------  ----------------------------------------------
* jdejong    2002-05-08 imported
*
*/
#define _POSIX_SOURCE_1
#include "vltPort.h"

/* $Id: history.c,v 1.4 2002/05/08 21:34:35 jdejong Exp $ */

/*----------------------------------------------------------------------- */
/* Routines for history keywords in FITS headers                          */
/*----------------------------------------------------------------------- */
#include "history.h"

void copy_history (fitsfile *infptr, fitsfile *outfptr, int *ierr)
/*----------------------------------------------------------------------- */
/*   Copies history records from one open FITS unit to another            */
/*   Inputs                                                               */
/*      infptr   cfitsio pointer to open input FITS file                  */
/*      outfptr   cfitsio pointer to open output FITS file                */
/*   Output:                                                              */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*----------------------------------------------------------------------- */
{
  int  i, number, morekey;
  char hiline[FLEN_CARD];

  if (*ierr!=0) return;  /* existing error condition? */
  if (infptr==NULL)  return; /* sanity check */
  if (outfptr==NULL) return; /* sanity check */


  /* how many are there? */
  fits_get_hdrspace (infptr, &number, &morekey, ierr);
  if (*ierr!=0) return;

  /* loop over input keywords copying history to output until END */
  for (i=1; i<=number; i++) {
    fits_read_record(infptr, i, hiline, ierr);
    if (*ierr!=0) break;
    if (!strncmp(hiline, "END     ", 8)) break; /* done? */
    if (!strncmp(hiline, "HISTORY ", 8)) /* found one - write it */
      fits_write_record(outfptr, hiline, ierr);
  } /* end loop copying history keywords */
} /* end copy_history */
  
void history_time (char *timestr)
/*----------------------------------------------------------------------- */
/*   Gets the current date/time string suitable for history               */
/*   Input/Output:                                                        */
/*      timestr      character large enouthg (>30) for the time string    */
/*----------------------------------------------------------------------- */
{
  char *tt;
  time_t t;
  t = time(NULL);  /* current time */
  tt = ctime(&t);  /* convert to string */
  strncpy (timestr, tt, strlen(tt)-1); /* strip linefeed */
  timestr[strlen(tt)-1] = 0;           /* now terminate */
} /* end history_time */
/* */
